# Examples

This section includes our tutorials to learn how to better leverage 🕵️‍♀️ **Variationist** for exploring language variation and bias in written language data, including a set of case studies using real-world datasets.

| Tutorial name | Notebook |
| ----------- | -------- |
| Quickstart | [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/dhfbk/variationist/blob/main/examples/Variationist-Quickstart.ipynb) |
| Example 1: Custom Tokenizers | [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://github.com/dhfbk/variationist/blob/main/examples/Variationist%20-%20Example%201%3A%20Custom%20Tokenizers.ipynb) |
| Example 2: Custom Metrics | [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://github.com/dhfbk/variationist/blob/main/examples/Variationist%20-%20Example%202%3A%20Custom%20Metrics.ipynb) |

| Case study name | Notebook |
| ----------- | -------- |
| Case study 1: Exploring Language Variation Across Space and Time | [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://github.com/dhfbk/variationist/blob/main/examples/Variationist%20-%20Use%20Case%201%3A%20Language%20Variation%20Across%20Space%20and%20Time.ipynb) |
| Case study 2: Understanding Human Subjectivity in Hate Speech Annotation | [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://github.com/dhfbk/variationist/blob/main/examples/Variationist%20-%20Use%20Case%202%3A%20Human%20Subjectivity%20in%20Hate%20Speech%20Annotation.ipynb) |
| Case study 3: Grasping Features of Human vs Generated Texts | [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://github.com/dhfbk/variationist/blob/main/examples/Variationist%20-%20Use%20Case%203%3A%20Grasping%20Features%20of%20Human%20vs%20Generated%20Texts.ipynb) |
